ComConfig class
Constructors
ComConfig ({Encoding ? encoding , String ? preferredProtocol , String ? mainHost , dynamic onConnectionLose ()?, dynamic preDecorder (dynamic )? })
Properties
encoding
→ Encoding
UTF-8 by default
final
hashCode
→ int
The hash code for this object.
no setter inherited
mainHost
→ String ?
If you set this property you will be able to use ComRequest without spedifieing host property.
final
onConnectionLose
→ dynamic Function() ?
This function is called when internet connection is lost.
final
preDecorder
→ dynamic Function(dynamic ) ?
Predecoder should be used to decode the response body before passing it to the decoder.
It is useful when your API returns payload where your targer object is wrapped in other property. For example User payload like this:
final
preferredProtocol
→ String ?
final
runtimeType
→ Type
A representation of the runtime type of the object.
no setter inherited
Methods
noSuchMethod (Invocation invocation )
→ dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString ()
→ String
A string representation of this object.
inherited